rse.main.config package — The Research Software Encyclopedia 11 documentation

# rse.main.config package

## Module contents

Copyright (C) 2020 Vanessa Sochat.

This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

class rse.main.config.Config(config_file='rse.ini', load=True, generate=False)

  Bases: `object`

  get(section, key)

    A wrapper to config.get to directly interact with the self.config

  read(configfile=None)

    read in configuration file. By default use self.configfile.

  save()

    save configuration back to it’s original file

  update(section, key, value, save=False)

    update client secrets will update the data structure for a particular authentication. This should only be used for a (quasi permanent) token or similar. The secrets file, if found, is updated and saved by default.